<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: download.php 5565 2006-08-14 09:18:01Z toddy $
#
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
#
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


if (isset($item_file_id)) 
{
  $file_id = $item_file_id;
}

# check if the provided file_id is a valid numerical id
if (!$file_id || !ctype_digit($file_id))
{
  exit_missing_param();
}

$sql="SELECT filename,filesize FROM trackers_file WHERE file_id='$file_id' LIMIT 1";
$result=db_query($sql);

if ($result && db_numrows($result) > 0) 
{

  if (db_result($result,0,'filesize') == 0) 
    {
      
      exit_error(_('Nothing in here - File has a null size'));
      
    } 
  else 
    {
      # Redirect to an url that will pretend the file really exists with
      # this name, so all browsers will propose its name as filename when
      # saving it.
      session_redirect($GLOBALS['sys_home'].'file/'.db_result($result,0,'filename').'?file_id='.$file_id);

    }

} 
else
{
  exit_error(_("Couldn't find attached file")." (file #$file_id)");
}

?>
